Documentation
¶
Overview ¶
templ: version: v0.3.960
templ: version: v0.3.960
Index ¶
- func Breadcrumb(args BreadcrumbArgs) templ.Component
- func BreadcrumbEllipsis(args BreadcrumbEllipsisArgs) templ.Component
- func BreadcrumbItem(args BreadcrumbItemArgs) templ.Component
- func BreadcrumbLink(args BreadcrumbLinkArgs) templ.Component
- func BreadcrumbList(args BreadcrumbListArgs) templ.Component
- func BreadcrumbPage(args BreadcrumbPageArgs) templ.Component
- func BreadcrumbSeparator(args BreadcrumbSeparatorArgs) templ.Component
- func FromItems(items []BreadcrumbItemData) templ.Component
- type BreadcrumbArgs
- type BreadcrumbEllipsisArgs
- type BreadcrumbItemArgs
- type BreadcrumbItemData
- type BreadcrumbLinkArgs
- type BreadcrumbListArgs
- type BreadcrumbPageArgs
- type BreadcrumbSeparatorArgs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Breadcrumb ¶
func Breadcrumb(args BreadcrumbArgs) templ.Component
Breadcrumb renders the main navigation wrapper
func BreadcrumbEllipsis ¶
func BreadcrumbEllipsis(args BreadcrumbEllipsisArgs) templ.Component
BreadcrumbEllipsis renders an ellipsis indicator for collapsed breadcrumbs
func BreadcrumbItem ¶
func BreadcrumbItem(args BreadcrumbItemArgs) templ.Component
BreadcrumbItem renders a list item wrapper for breadcrumb content
func BreadcrumbLink ¶
func BreadcrumbLink(args BreadcrumbLinkArgs) templ.Component
BreadcrumbLink renders a clickable breadcrumb link
func BreadcrumbList ¶
func BreadcrumbList(args BreadcrumbListArgs) templ.Component
BreadcrumbList renders the ordered list container for breadcrumb items
func BreadcrumbPage ¶
func BreadcrumbPage(args BreadcrumbPageArgs) templ.Component
BreadcrumbPage renders the current page indicator (non-clickable)
func BreadcrumbSeparator ¶
func BreadcrumbSeparator(args BreadcrumbSeparatorArgs) templ.Component
BreadcrumbSeparator renders the separator between breadcrumb items
func FromItems ¶
func FromItems(items []BreadcrumbItemData) templ.Component
FromItems creates a breadcrumb navigation from a slice of items This is a higher-level helper that handles the manual construction of breadcrumbs
Types ¶
type BreadcrumbArgs ¶
type BreadcrumbArgs struct {
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
}
BreadcrumbArgs defines the properties for the Breadcrumb nav component
type BreadcrumbEllipsisArgs ¶
type BreadcrumbEllipsisArgs struct {
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
}
BreadcrumbEllipsisArgs defines the properties for the BreadcrumbEllipsis span component
type BreadcrumbItemArgs ¶
type BreadcrumbItemArgs struct {
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
}
BreadcrumbItemArgs defines the properties for the BreadcrumbItem li component
type BreadcrumbItemData ¶
type BreadcrumbItemData struct {
Label string
Href string // Empty string means this is the current page (uses BreadcrumbPage instead of BreadcrumbLink)
}
BreadcrumbItemData represents a single breadcrumb item
type BreadcrumbLinkArgs ¶
type BreadcrumbLinkArgs struct {
// AsChild renders the link as a child element (for composition)
AsChild bool
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
// Href specifies the URL for the link
Href string
}
BreadcrumbLinkArgs defines the properties for the BreadcrumbLink a component
type BreadcrumbListArgs ¶
type BreadcrumbListArgs struct {
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
}
BreadcrumbListArgs defines the properties for the BreadcrumbList ol component
type BreadcrumbPageArgs ¶
type BreadcrumbPageArgs struct {
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
}
BreadcrumbPageArgs defines the properties for the BreadcrumbPage span component
type BreadcrumbSeparatorArgs ¶
type BreadcrumbSeparatorArgs struct {
// Class allows additional CSS classes to be added
Class string
// Attributes allows additional HTML attributes to be added
Attributes templ.Attributes
// CustomIcon allows overriding the default ChevronRight icon
CustomIcon bool
}
BreadcrumbSeparatorArgs defines the properties for the BreadcrumbSeparator li component